@@ -22,11 +22,13 @@
 #  include <config.h>
 #endif
 
+#include <Python.h>
+#include <glib-object.h>
+
 #include <pyglib.h>
-#include "pygobject-private.h"
 #include "pygboxed.h"
+#include "pygtype.h"
 
-#include "pygi.h"
 #include "pygi-type.h"
 
 GQuark pygboxed_type_key;
@@ -38,9 +40,9 @@ static void
 pyg_boxed_dealloc(PyGBoxed *self)
 {
     if (self->free_on_dealloc && pyg_boxed_get_ptr (self)) {
-	PyGILState_STATE state = pyglib_gil_state_ensure();
+	PyGILState_STATE state = PyGILState_Ensure();
 	g_boxed_free (self->gtype, pyg_boxed_get_ptr (self));
-	pyglib_gil_state_release(state);
+	PyGILState_Release(state);
     }
 
     Py_TYPE(self)->tp_free((PyObject *)self);
@@ -61,10 +63,10 @@ pyg_boxed_richcompare(PyObject *self, PyObject *other, int op)
 }
 
 
-static long
+static PYGLIB_Py_hash_t
 pyg_boxed_hash(PyGBoxed *self)
 {
-    return (long)pyg_boxed_get_ptr (self);
+    return PYGLIB_Py_hash_t_FromVoidPtr (pyg_boxed_get_ptr (self));
 }
 
 static PyObject *
@@ -202,11 +204,11 @@ pyg_boxed_new(GType boxed_type, gpointer boxed, gboolean copy_boxed,
     g_return_val_if_fail(boxed_type != 0, NULL);
     g_return_val_if_fail(!copy_boxed || (copy_boxed && own_ref), NULL);
 
-    state = pyglib_gil_state_ensure();
+    state = PyGILState_Ensure();
 
     if (!boxed) {
 	Py_INCREF(Py_None);
-	pyglib_gil_state_release(state);
+	PyGILState_Release(state);
 	return Py_None;
     }
 
@@ -220,14 +222,14 @@ pyg_boxed_new(GType boxed_type, gpointer boxed, gboolean copy_boxed,
 
     if (!PyType_IsSubtype (tp, &PyGBoxed_Type)) {
         PyErr_Format (PyExc_RuntimeError, "%s isn't a GBoxed", tp->tp_name);
-        pyglib_gil_state_release (state);
+        PyGILState_Release (state);
         return NULL;
     }
 
     self = (PyGBoxed *)tp->tp_alloc(tp, 0);
 
     if (self == NULL) {
-	pyglib_gil_state_release(state);
+	PyGILState_Release(state);
         return NULL;
     }
 
@@ -237,7 +239,7 @@ pyg_boxed_new(GType boxed_type, gpointer boxed, gboolean copy_boxed,
     self->gtype = boxed_type;
     self->free_on_dealloc = own_ref;
 
-    pyglib_gil_state_release(state);
+    PyGILState_Release(state);
     
     return (PyObject *)self;
 }
